:orphan:

**Before continuing** make sure you have a working Salt installation by
following the `installation`_ and the :doc:`configuration
</topics/configuration>` instructions.

.. admonition:: Stuck?

    If you get stuck at any point, there are many ways to :doc:`get help from
    the Salt community </topics/community>` including our mailing list and our
    IRC channel.
